==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/ToolActionRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionRadioDescription } from "./ToolActionRadioDescription";
/**
 * @hidden
 */
var ToolActionRadioDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionRadioDescriptionMetadata, _super);
    function ToolActionRadioDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionRadioDescriptionMetadata.b = function (a) {
        if (ToolActionRadioDescriptionMetadata.a == null) {
            ToolActionRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionRadioDescriptionMetadata.c(ToolActionRadioDescriptionMetadata.a);
        }
        if (a.j(ToolActionRadioDescriptionMetadata.a)) {
            return;
        }
        a.y(ToolActionRadioDescriptionMetadata.a);
    };
    ToolActionRadioDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("RadioGroup", "String");
    };
    ToolActionRadioDescriptionMetadata.d = function (a) {
        ToolActionRadioDescriptionMetadata.b(a);
        a.aa("ToolActionRadio", function () { return new ToolActionRadioDescription(); });
        a.z("ToolActionRadio", ToolActionRadioDescriptionMetadata.a);
    };
    ToolActionRadioDescriptionMetadata.$t = markType(ToolActionRadioDescriptionMetadata, 'ToolActionRadioDescriptionMetadata');
    ToolActionRadioDescriptionMetadata.a = null;
    return ToolActionRadioDescriptionMetadata;
}(Base));
export { ToolActionRadioDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/ToolActionRadioDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ToolActionDescriptionMetadata } from "./ToolActionDescriptionMetadata";
import { ToolActionRadioDescription } from "./ToolActionRadioDescription";
/**
 * @hidden
 */
var ToolActionRadioDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(ToolActionRadioDescriptionMetadata, _super);
    function ToolActionRadioDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    ToolActionRadioDescriptionMetadata.b = function (a) {
        if (ToolActionRadioDescriptionMetadata.a == null) {
            ToolActionRadioDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            ToolActionRadioDescriptionMetadata.c(ToolActionRadioDescriptionMetadata.a);
        }
        if (a.k(ToolActionRadioDescriptionMetadata.a)) {
            return;
        }
        a.aa(ToolActionRadioDescriptionMetadata.a);
    };
    ToolActionRadioDescriptionMetadata.c = function (a) {
        ToolActionDescriptionMetadata.c(a);
        a.item("RadioGroup", "String");
    };
    ToolActionRadioDescriptionMetadata.d = function (a) {
        ToolActionRadioDescriptionMetadata.b(a);
        a.ac("ToolActionRadio", function () { return new ToolActionRadioDescription(); });
        a.ab("ToolActionRadio", ToolActionRadioDescriptionMetadata.a);
    };
    ToolActionRadioDescriptionMetadata.$t = markType(ToolActionRadioDescriptionMetadata, 'ToolActionRadioDescriptionMetadata');
    ToolActionRadioDescriptionMetadata.a = null;
    return ToolActionRadioDescriptionMetadata;
}(Base));
export { ToolActionRadioDescriptionMetadata };
